ActivationLineState

Enum ActivationLineState 

pub enum ActivationLineState {
    Idle,
    Pending {
        source_address: u16,
        activation_type: ActivationType,
    },
    Active {
        source_address: u16,
        activation_type: ActivationType,
    },
    Deactivated {
        reason: ActivationDenialReason,
    },
}
The state of the logical activation line for a single TCP connection.

In vehicle terms this maps to the hardware activation line state. The line must be in Active before DiagnosticMessage frames are forwarded to ECU nodes.

Variants



Idle

No routing activation has been attempted on this connection.



Pending

A RoutingActivationRequest was received and is being processed.

Fields

source_address: u16
activation_type: ActivationType


Active

Routing activation succeeded - diagnostic messages permitted.

Fields

source_address: u16

Logical address of the activated tester.

activation_type: ActivationType

Activation type that was used to activate this connection.



Deactivated

Routing activation was denies or the line was dropped. The connection should be closed.

Implementations